#
# spec file for package dictd
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#



Name:           dictd
Version:        1.12.1
Release:        1.1
Summary:        DICT protocol (RFC 2229) server and command-line client
License:        GPL-1.0-or-later AND Zlib AND MIT
Group:          Productivity/Office/Dictionary
URL:            https://sourceforge.net/projects/dict/
Source0:        http://downloads.sourceforge.net/dict/%{name}-%{version}.tar.gz
Source1:        colorit.conf
Source2:        dictd.service
Patch0:         dictd-1.12.1-unused-return.patch
# https://bugzilla.redhat.com/show_bug.cgi?id=198359
# https://sourceforge.net/p/dict/feature-requests/4/
# Patch1:         dictd-1.9.15-ipv6.patch
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gawk
BuildRequires:  gcc
BuildRequires:  libdbi-devel
BuildRequires:  libmaa-devel
BuildRequires:  libtool
BuildRequires:  systemd
BuildRequires:  zlib-devel
# libtool-ltdl-devel  byacc
%if 0%{?suse_version}
BuildRequires: systemd-rpm-macros
%{?systemd_requires}
%endif

%description
This package contains two programs. With dict, you have access to
powerful electronic dictionaries on the Internet. With dictd, you can
set up your own dictionary. To look up, for example, the word 'grunt',
just type "dict grunt" at a command line. See the man pages of dict and
dictd for details.

%prep
%setup
%autopatch -p1

%build
export LDFLAGS="%{?__global_ldflags}" CPPFLAGS="$RPM_OPT_FLAGS -fPIC"
%configure --enable-dictorg --disable-plugin
make %{?_smp_mflags}

%install
%make_install
install -D -m 0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/colorit.conf
cat <<EOF > $RPM_BUILD_ROOT/%{_sysconfdir}/dictd.conf
global {
    #syslog
    #syslog_facility daemon
}

# Add database definitions here...

# We stop the search here
database_exit

# Add hidden database definitions here...

EOF

install -D -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/dictd.service

ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rcdictd

%pre
%service_add_pre dictd.service

%post
%service_add_post dictd.service
touch %{_localstatedir}/log/dictd
chmod 644 %{_localstatedir}/log/dictd

%preun
%service_del_preun dictd.service

%postun
%service_del_postun dictd.service

%files
%license COPYING
%doc ANNOUNCE ChangeLog NEWS README TODO example*
%doc doc/dicf.ms doc/rfc.ms doc/rfc2229.txt doc/security.doc
%{_bindir}/*
%{_sbindir}/*
%{_mandir}/man1/*
%{_mandir}/man8/*
%attr(0644,root,root) %{_unitdir}/dictd.service
%config(noreplace) %{_sysconfdir}/colorit.conf
%config(noreplace) %{_sysconfdir}/dictd.conf

%changelog
* Fri Oct 12 2012 mailaender@opensuse.org
- put libmma in a separate package
- update dictd to 1.12.1
  + Fix for Debian bug #677868 reported by Stepan Golosunov.
  + Fixes for mistypes found by A. Costa. Thanks!
  + Fix for sf.net bug #3390567 reported by Ivo Danihelka.
  + Fix for sf.net bug #3398178
  + Fix for option -c. Now it works correctly.
  + Fix incorrect keyword for virtual database.
  + fix in colorit: option -c now works correctly
  + Check return value of fwrite, fflush and fclose functions. This fixes sf bug #3390567
  + Fix for Debian bug #677868 reported by Stepan Golosunov.
  + dictd.8.in: fixes for mistypes found by A. Costa. Thanks!
  + INSTALL: Fix for sf.net bug #3398178
  + fix in dictd_virtual.conf: incorrect keyword for virtual database.
  + Makefile.in: Add -c to ${INSTALL} envocations
  + Makefile.in: fix for installing from obj directory
* Wed Feb 15 2012 lars@linux-schulserver.de
- update dictd to 1.12.0:
  + New script dict_lookup for translating words and phrases
  + dictfmt: Internal buffer size was increased from 10240 to
    102400 bytes
  + dictfmt: superfluous spaces are removed not only from the beginng
    and the end of a headword but also inside a multiword headwords.
  + dictfmt spawns sort command to sort the index. When there are
    several entries for the same headword, they get sorted BY OFFSET
    AND SIZE (in addition to headwords). As a result, the order of
    identical headwords is messed up.  To fix these problem -k1,3
    option is replaced with -k1,1.
  + FIX: When search is handled by dict_search_bmh() function, the
    first character from the first entry in the index file is
    missing. Usually this is some of 00-database-* entries.
  + Other minor fixes and cleanups
- update libmaa to 1.3.1:
  + Build failure with gcc-4.6 was fixed
  + Only maa's symbols are exported from libmaa shared library
    ^^ INCLUDES ABI INCOMPATIBILITIES
  + For better conformance with POSIX/SUS xmalloc, xrealloc and
    xcalloc functions take 'size_t' args, not 'unsigned int'.
- small init script beaufify
- split out devel package
* Mon Mar  2 2009 prusnak@suse.cz
- updated to 1.11.1
  * fixed installing plugins
  * DICTFMT sorts entries in 00-database-alphabet entry
    lexicographically, that is now this order doesn't depend on
    sizeof(long)
  * DICTFMT: 'dictfmt -I' never worked
* Fri Feb  6 2009 prusnak@suse.cz
- file /var/log/dictd is now pre-created [bnc#461234]
* Tue Nov  4 2008 prusnak@suse.cz
- add missing colorit.conf [bnc#441256]
* Thu Aug 14 2008 prusnak@suse.cz
- small cleanup of spec file
- fixed preun/postun scripts
* Mon Apr  7 2008 zpetrova@suse.cz
- update to version 1.10.11
  - fixed many compiler warnings/failures.
  - dictd: while processing MATCH command unicity of only first
    column of .index was checked, but not fourth column-> fixed.
  - timestamp log marker (log_option "timestamp") is changed
    from :T: to :t:
  - dictfmt: maximum length of headwords was limited to hardcoded
    constant. Now arrays are reallocated.
  - dict: new -F|--flush option for flushing stdout after each
    definition/match
  - colorit: bashism fixed: 'echo -en' -> more portable 'printf'.
* Sun Feb 17 2008 zpetrova@suse.cz
- update to version 1.10.10:
  - dictd: added support for utf-8 symbols other than BMP
  - dict, dictl, colorit do not support paging to a special program,
    i.e.  --pager|-P option. As of this version everything is output
    to stdout only. '-P -' option is allowed.
- fixed compiler warning (bug #361613)
* Thu Jul 12 2007 zpetrova@suse.cz
- update to version 1.10.9:
- added new keywords limit_{time,matches,definitions,queries} to
  dictd to prevent DOS attacks.
- support for the case-sensitive search.
- Two new search strategies, 'first' and 'last'.
- dict -f now enables formatted output for further processing
  by other utilities.
- clean up configure.in and Makefile.in
* Thu Mar 29 2007 dmueller@suse.de
- update BuildRequires
* Fri Jul  7 2006 zpetrova@suse.cz
- update to version 1.10.6
* Wed Jun 28 2006 zpetrova@suse.cz
- update to version 1.10.5
- added configure --enable_dictorg (#169995)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 17 2006 zpetrova@suse.cz
- fixed build.
* Mon Jan 16 2006 zpetrova@suse.cz
- update to version 1.10.4
* Thu Apr 21 2005 zpetrova@suse.cz
- dictd-gcc4.patch: make dictd compilable with gcc-4.0
* Sun Apr 25 2004 ro@suse.de
- added missing return value (unreached code)
* Sun Jan 11 2004 adrian@suse.de
- add %%defattr
* Thu May 22 2003 coolo@suse.de
- use BuildRoot
* Wed Nov 13 2002 ro@suse.de
- fix for current bison (end all rules with ";")
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Mon Aug 19 2002 mmj@suse.de
- Correct PreReq
* Thu Apr 25 2002 uwedr@suse.de
- Removed dictd.conf from specfile. It was not used and examples are
  in /usr/share/doc/packages/dictd anyway.
* Tue Apr 23 2002 schwab@suse.de
- Fix for 64 bit platforms.
- Use RPM_OPT_FLAGS.
* Mon Jan 14 2002 ro@suse.de
- removed START_DICTD
* Wed Dec 12 2001 uwedr@suse.de
- Added some hints in dictd.conf how to install local dictionaris
- Logging to /var/log/dictd  (see startup in /etc/init.d/dictd)
* Wed Jun  6 2001 ro@suse.de
- mark used files as Source
* Wed May 30 2001 uwedr@suse.de
- improved spec file (#7139):
  no more --with-qt and some paths corrected
- new rc.config variable START_DICTD and init script added, so the
  server dictd can be started now (if /etc/dictd.conf is configured
  properly and at least one dictionary is installed)
* Sat Dec  9 2000 nashif@suse.de
- sorted
* Tue Feb 15 2000 ro@suse.de
- man to /usr/share using macro
* Tue Feb 15 2000 aj@suse.de
- Removed prototypes for SunOS/Solaris.
* Fri Sep 17 1999 kettner@suse.de
- Reinserted old # Commandline: line.
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Apr 27 1999 ro@suse.de
- fixed: dict.c: stdout is not constant
* Fri Apr  9 1999 kettner@suse.de
- Created spec file from dictd-1.4.9.tar.gz using autospec script
